/*
 * interruptions
 *
 * Tested on:
 * Microstick
 *
 * File name: crc.h
 * Author:    Eduardo Lopes
 * Info:      elopes_74@hotmail.com
 *
 * Last modification: 03-11-2013
 */

#ifndef _INTERRUPTS_H
#define _INTERRUPTS_H

/*---------------------------------------------------------------------
  Function name: _U1RXInterrupt
  Description: RECEBE caracter da usart1
  Input parameters: -
  Output parameters: -
-----------------------------------------------------------------------*/
void _U1RXInterrupt(void);

/*---------------------------------------------------------------------
  Function name: _U1TXInterrupt
  Description: TRANSMITE caracter para usart1
  Input parameters: -
  Output parameters: -
-----------------------------------------------------------------------*/
void _U1TXInterrupt(void);

/*---------------------------------------------------------------------
  Function name: _U2Interrupt
  Description: RECEBE caracter da usart2
  Input parameters: -
  Output parameters: -
-----------------------------------------------------------------------*/
//;;*********************************************************************************************************
//;                               Interrupt Service Routine
//;
//; Only RTCC Inturrupt Is used. RTCC Inturrupt is used as timing for Serial Port Receive & Transmit
//; Since RS-232 is implemented only as a Half Duplex System, The RTCC is shared by both Receive &
//; Transmit Modules.
//;       Transmission :
//;                       RTCC is setup for Internal Clock increments and interrupt is generated when
//;                       RTCC overflows. Prescaler is assigned, depending on The INPUT CLOCK & the
//;                       desired BAUD RATE.
//;       Reception :
//;                       When put in receive mode, RTCC is setup for external clock mode (FALLING EDGE)
//;                       and preloaded with 0xFF. When a Falling Edge is detected on RTCC Pin, RTCC
//;                       rolls over and an Interrupt is generated (thus Start Bit Detect). Once the start
//;                       bit is detected, RTCC is changed to INTERNAL CLOCK mode and RTCC is preloaded
//;                       with a certain value for regular timing interrupts to Poll RTCC Pin (i.e RX pin).
//;
//;*********************************************************************************************************
void _U2Interrupt(void);

/******************************************************************************/
/* Default Interrupt Handler                                                  */
/*                                                                            */
/* This executes when an interrupt occurs for an interrupt source with an     */
/* improperly defined or undefined interrupt handling routine.                */
/******************************************************************************/
void _DefaultInterrupt(void);

#endif
