/* Device header file */
#if defined(__XC)
#include <xc.h>         /* XC8 General Include File */
#endif

#include "rn41.h"
#include "user.h"
#include "uart2.h"

// responses to parse
enum{
 BT_CMD = 1,
 BT_AOK,
 BT_CONN,
 BT_END
};
static char *CmdMode = "$$$";
static char *NameDevice = "SN,Bluetooth-Slave\r"; //CR
static char *ExtStatString = "SO,Slave\r";
static char *SetMode = "SM,0\r";
static char *Authentication = "SA,1\r";
static char *SecPinCode = "SP,mikroe\r";
static char *CmdExit = "---\r";

//;*********************************************************************************************************
//;				Initialize RN41 module
//;
//;
//;*********************************************************************************************************

void Rn41Init() {
    char len;

    Delay_ms(1500);
    len = strlen(CmdMode);
    do {
        ser2Outstring(CmdMode, len); // Enter command mode
        Delay_ms(500);
    }while(BT_Get_Response() != BT_CMD);

    len = strlen(NameDevice);
    do {
        ser2Outstring(NameDevice, len); // Name of device
        Delay_ms(500);
    } while (BT_Get_Response() != BT_AOK);

    len = strlen(ExtStatString);
    do {
        ser2Outstring(ExtStatString, len); // Extended status string
        Delay_ms(500);
    } while (BT_Get_Response() != BT_AOK);

    len = strlen(SetMode);
    do {
        ser2Outstring(SetMode, len); // Set mode (0 = slave, 1 = master, 2 = trigger, 3 = auto, 4 = DTR, 5 = ANY)
        Delay_ms(500);
    } while (BT_Get_Response() != BT_AOK);

    len = strlen(Authentication);
    do {
        ser2Outstring(Authentication, len); // Authentication (1 to enable, 0 to disable)
        Delay_ms(500);
    } while (BT_Get_Response() != BT_AOK);

    len = strlen(SecPinCode);
    do {
        ser2Outstring(SecPinCode, len); // Security pin code (mikroe)
        Delay_ms(500);
    } while (BT_Get_Response() != BT_AOK);

    len = strlen(CmdExit);
    do {
        ser2Outstring(CmdExit, len); // Security pin code (mikroe)
        Delay_ms(500);
    } while (BT_Get_Response() != BT_END);

    while (BT_Get_Response() != BT_CONN);
}

// Get BlueTooth response, if there is any

char BT_Get_Response() {
    char tmp;
    char BT_state = 0;
    char response_rcvd = 0;
    char responseID = 0;

    do {
        do{
        tmp = ser2Inchar(); // Get received byte
        }while(!BufferEmpty);
        /* The responses expected from the EasyBT module:
        CMD
        AOK
        AOK
        AOK
        AOK
        AOK
        END
        SlaveCONNECTmikroE
        EasyBlueTooth
        mikroE ...
        EasyBlueTooth*/


        // Process reception through state machine
        // We are parsing CMD<cr><lf>, AOK<cr><lf>, CONN<cr> and END<cr><lf> responses
        switch (BT_state) {
            case 0:
            {
                responseID = 0; // Clear response
                if (tmp == 'C') // We have 'C', it could be CMD<cr><lf>  or CONN
                    BT_state = 1; // Expecting 'M' or 'N'
                if (tmp == 'A') // We have 'A', it could be AOK<cr><lf>
                    BT_state = 11; // expecting 'O'
                if (tmp == 'E') // We have 'E', it could be END<cr><lf>
                    BT_state = 31; // expecting 'N'
                break; // ...
            }

            case 1:
            {
                if (tmp == 'M')
                    BT_state = 2;
                else if (tmp == 'O')
                    BT_state = 22;
                else
                    BT_state = 0;
                break;
            }


            case 2:
            {
                if (tmp == 'D') {
                    responseID = BT_CMD; // CMD
                    BT_state = 40;
                } else
                    BT_state = 0;
                break;
            }


            case 11:
            {
                if (tmp == 'O')
                    BT_state = 12;
                else
                    BT_state = 0;
                break;
            }

            case 12:
            {
                if (tmp == 'K') {
                    responseID = BT_AOK; // AOK
                    BT_state = 40;
                } else
                    BT_state = 0;
                break;
            }


            case 22:
            {
                if (tmp == 'N')
                    BT_state = 23;
                else
                    BT_state = 0;
                break;
            }

            case 23:
            {
                if (tmp == 'N') {
                    responseID = BT_CONN; // SlaveCONNECTmikroE
                    response_rcvd = 1;
                }
                BT_state = 0;
                break;
            }

            case 31:
            {
                if (tmp == 'N')
                    BT_state = 32;
                else
                    BT_state = 0;
                break;
            }

            case 32:
            {
                if (tmp == 'D') {
                    responseID = BT_END; // END
                    BT_state = 40;
                } else
                    BT_state = 0;
                break;
            }

            case 40:
            {
                if (tmp == 13)
                    BT_state = 41;
                else
                    BT_state = 0;
                break;
            }


            case 41:
            {
                if (tmp == 10) {
                    response_rcvd = 1;
                }
                BT_state = 0;
                break;
            }

            default:
            {
                BT_state = 0;
                break;
            }
        }
    } while (!response_rcvd);
    return responseID;
}
